# GenerateBillingDocumentRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**auto_post** | **bool** | Whether to automatically post the billing documents after the draft billing documents are generated.   If an error occurs during posting billing documents, the draft billing documents are not generated too.  | [optional] [default to False]
**auto_renew** | **bool** | Whether to automatically renew the subscriptions with **Auto Renew** set to **Yes**.   | [optional] [default to False]
**charge_type_to_exclude** | **List[str]** | The types of the charges to be excluded from the generation of billing documents. The field values are case insensitive. Supported values include &#x60;onetime&#x60;, &#x60;recurring&#x60;, and &#x60;usage&#x60;.   | [optional] 
**credit_memo_reason_code** | **str** | A code identifying the reason for the credit memo transaction that is generated by the request. The value must be an existing reason code. If you do not pass the field or pass the field with empty value, Zuora uses the default reason code. | [optional] 
**effective_date** | **date** | The date on which to generate the billing documents, in &#x60;yyyy-mm-dd&#x60; format.  | [optional] 
**subscription_ids** | **List[str]** | The IDs of the subscriptions that you want to create the billing documents for. Each value must be the ID of the latest version of an active subscription.  | [optional] 
**target_date** | **date** | The date used to determine which charges are to be billed, in &#x60;yyyy-mm-dd&#x60; format.  | [optional] 
**include_subscriptions** | **bool** | Whether to bill subscriptions.  | [optional] 
**include_order_line_items** | **bool** | Whether to bill order line items.  | [optional] 

## Example

```python
from zuora_sdk.models.generate_billing_document_request import GenerateBillingDocumentRequest

# TODO update the JSON string below
json = "{}"
# create an instance of GenerateBillingDocumentRequest from a JSON string
generate_billing_document_request_instance = GenerateBillingDocumentRequest.from_json(json)
# print the JSON string representation of the object
print(GenerateBillingDocumentRequest.to_json())

# convert the object into a dict
generate_billing_document_request_dict = generate_billing_document_request_instance.to_dict()
# create an instance of GenerateBillingDocumentRequest from a dict
generate_billing_document_request_from_dict = GenerateBillingDocumentRequest.from_dict(generate_billing_document_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


